@@ -11,10 +11,10 @@ use Scalar::Util qw(blessed);
 
 Readonly::Array our @EXPORT_OK => qw(check_angle check_array check_array_object
 	check_array_required check_bool check_code check_isa check_length
-	check_number check_number_of_items check_regexp check_required
-	check_string_begin check_strings);
+	check_length_fix check_number check_number_of_items check_regexp
+	check_required check_string_begin check_strings);
 
-our $VERSION = 0.21;
+our $VERSION = 0.22;
 
 sub check_angle {
 	my ($self, $key) = @_;
@@ -138,6 +138,20 @@ sub check_length {
 	return;
 }
 
+sub check_length_fix {
+	my ($self, $key, $length) = @_;
+
+	_check_key($self, $key) && return;
+
+	if (length $self->{$key} != $length) {
+		err "Parameter '$key' has length different than '$length'.",
+			'Value', $self->{$key},
+		;
+	}
+
+	return;
+}
+
 sub check_number {
 	my ($self, $key) = @_;
 
@@ -301,6 +315,7 @@ Mo::utils - Mo utilities.
  check_code($self, $key);
  check_isa($self, $key, $class);
  check_length($self, $key, $max_length);
+ check_length_fix($self, $key, $length);
  check_number($self, $key);
  check_number_of_items($self, $list_method, $item_method, $object_name, $item_name);
  check_regexp($self, $key, $regexp);
@@ -318,6 +333,8 @@ Mo utilities for checking of data objects.
 
  check_angle($self, $key);
 
+I<Since version 0.20.>
+
 Check parameter defined by C<$key> which is number between 0 and 360.
 
 Put error if check isn't ok.
@@ -328,6 +345,8 @@ Returns undef.
 
  check_array($self, $key);
 
+I<Since version 0.06.>
+
 Check parameter defined by C<$key> which is reference to array.
 
 Put error if check isn't ok.
@@ -338,6 +357,8 @@ Returns undef.
 
  check_array_object($self, $key, $class, $class_name);
 
+I<Since version 0.02. Described functionality since version 0.21.>
+
 Check parameter defined by C<$key> which is reference to array with instances
 of some object type (C<$class>). C<$class_name> is used to error message.
 
@@ -349,6 +370,8 @@ Returns undef.
 
  check_array_required($self, $key);
 
+I<Since version 0.18. Described functionality since version 0.19.>
+
 Check parameter defined by C<$key> which is reference to array for at least one
 value inside.
 
@@ -360,6 +383,8 @@ Returns undef.
 
  check_bool($self, $key);
 
+I<Since version 0.06.>
+
 Check parameter defined by C<$key> if value is bool or not.
 
 Put error if check isn't ok.
@@ -370,6 +395,8 @@ Returns undef.
 
  check_code($self, $key);
 
+I<Since version 0.12.>
+
 Check parameter defined by C<$key> which is code reference or no.
 
 Put error if check isn't ok.
@@ -380,6 +407,8 @@ Returns undef.
 
  check_isa($self, $key, $class);
 
+I<Since version 0.01. Described functionality since version 0.08.>
+
 Check parameter defined by C<$key> which is instance of C<$class> or no.
 
 Put error if check isn't ok.
@@ -390,6 +419,8 @@ Returns undef.
 
  check_length($self, $key, $max_length);
 
+I<Since version 0.04. Described functionality since version 0.05.>
+
 Check length of value for parameter defined by C<$key>. Maximum length is
 defined by C<$max_length>.
 
@@ -397,10 +428,24 @@ Put error if check isn't ok.
 
 Returns undef.
 
+=head2 C<check_length_fix>
+
+ check_length_fix($self, $key, $length);
+
+I<Since version 0.22.>
+
+Check fixed length of value for parameter defined by C<$key>. Length is defined by C<$length> variable.
+
+Put error if check isn't ok.
+
+Returns undef.
+
 =head2 C<check_number>
 
  check_number($self, $key);
 
+I<Since version 0.01. Described functionality since version 0.09.>
+
 Check parameter defined by C<$key> which is number (positive or negative) or no.
 
 Put error if check isn't ok.
@@ -411,6 +456,8 @@ Returns undef.
 
  check_number_of_items($self, $list_method, $item_method, $object_name, $item_name);
 
+I<Since version 0.01.>
+
 Check amount of unique items defined by C<$item_method> method value.
 List items via C<$list_method> and get value via C<$item_method> method.
 C<$object_name> and C<$item_name> are variables for error output.
@@ -423,6 +470,8 @@ Returns undef.
 
  check_regexp($self, $key, $regexp);
 
+I<Since version 0.17.>
+
 Check parameter defined by C<$key> via regular expression defined by c<$regexp>.
 
 Put error if check isn't ok.
@@ -433,6 +482,8 @@ Returns undef.
 
  check_required($self, $key);
 
+I<Since version 0.01.>
+
 Check required parameter defined by C<$key>.
 
 Put error if check isn't ok.
@@ -443,6 +494,8 @@ Returns undef.
 
  check_string_begin($self, $key, $string_base);
 
+I<Since version 0.16.>
+
 Check parameter if it is correct string which begins with base.
 
 Put error if string base doesn't exist.
@@ -454,6 +507,8 @@ Returns undef.
 
  check_strings($self, $key, $strings_ar);
 
+I<Since version 0.15.>
+
 Check parameter if it is correct string from strings list.
 
 Put error if strings definition is undef or not list of strings.
@@ -507,6 +562,10 @@ Returns undef.
          Parameter '%s' has length greater than '%s'.
                  Value: %s
 
+ check_length_fix():
+         Parameter '%s' has length different than '%s'.
+                 Value: %s
+
  check_number():
          Parameter '%s' must be a number.
                  Value: %s
@@ -890,6 +949,50 @@ Returns undef.
 
 =head1 EXAMPLE17
 
+=for comment filename=check_length_fix_ok.pl
+
+ use strict;
+ use warnings;
+
+ $Error::Pure::TYPE = 'Error';
+
+ use Mo::utils qw(check_length_fix);
+
+ my $self = {
+         'key' => 'foo',
+ };
+ check_length_fix($self, 'key', 3);
+
+ # Print out.
+ print "ok\n";
+
+ # Output like:
+ # ok
+
+=head1 EXAMPLE18
+
+=for comment filename=check_length_fix_fail.pl
+
+ use strict;
+ use warnings;
+
+ $Error::Pure::TYPE = 'Error';
+
+ use Mo::utils qw(check_length_fix);
+
+ my $self = {
+         'key' => 'foo',
+ };
+ check_length_fix($self, 'key', 4);
+
+ # Print out.
+ print "ok\n";
+
+ # Output like:
+ # #Error [...utils.pm:?] Parameter 'key' has length different than '4'.
+
+=head1 EXAMPLE19
+
 =for comment filename=check_number_ok.pl
 
  use strict;
@@ -908,7 +1011,7 @@ Returns undef.
  # Output:
  # ok
 
-=head1 EXAMPLE18
+=head1 EXAMPLE20
 
 =for comment filename=check_number_fail.pl
 
@@ -930,7 +1033,7 @@ Returns undef.
  # Output like:
  # #Error [...utils.pm:?] Parameter 'key' must be a number.
 
-=head1 EXAMPLE19
+=head1 EXAMPLE21
 
 =for comment filename=check_number_of_items_ok.pl
 
@@ -975,7 +1078,7 @@ Returns undef.
  # Output like:
  # ok
 
-=head1 EXAMPLE20
+=head1 EXAMPLE22
 
 =for comment filename=check_number_of_items_fail.pl
 
@@ -1020,7 +1123,7 @@ Returns undef.
  # Output like:
  # #Error [...utils.pm:?] Test for Item 'value1' has multiple values.
 
-=head1 EXAMPLE21
+=head1 EXAMPLE23
 
 =for comment filename=check_regexp_ok.pl
 
@@ -1040,7 +1143,7 @@ Returns undef.
  # Output:
  # ok
 
-=head1 EXAMPLE22
+=head1 EXAMPLE24
 
 =for comment filename=check_regexp_fail.pl
 
@@ -1063,7 +1166,7 @@ Returns undef.
  # Output like:
  # #Error [...utils.pm:?] Parameter 'key' does not match the specified regular expression.
 
-=head1 EXAMPLE23
+=head1 EXAMPLE25
 
 =for comment filename=check_required_ok.pl
 
@@ -1083,7 +1186,7 @@ Returns undef.
  # Output:
  # ok
 
-=head1 EXAMPLE24
+=head1 EXAMPLE26
 
 =for comment filename=check_required_fail.pl
 
@@ -1106,7 +1209,7 @@ Returns undef.
  # Output like:
  # #Error [...utils.pm:?] Parameter 'key' is required.
 
-=head1 EXAMPLE25
+=head1 EXAMPLE27
 
 =for comment filename=check_string_begin_ok.pl
 
@@ -1126,7 +1229,7 @@ Returns undef.
  # Output:
  # ok
 
-=head1 EXAMPLE26
+=head1 EXAMPLE28
 
 =for comment filename=check_string_begin_fail.pl
 
@@ -1149,7 +1252,7 @@ Returns undef.
  # Output like:
  # #Error [...utils.pm:?] Parameter 'key' must begin with defined string base.
 
-=head1 EXAMPLE27
+=head1 EXAMPLE29
 
 =for comment filename=check_strings_ok.pl
 
@@ -1169,7 +1272,7 @@ Returns undef.
  # Output:
  # ok
 
-=head1 EXAMPLE28
+=head1 EXAMPLE30
 
 =for comment filename=check_strings_fail.pl
 
@@ -1240,6 +1343,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.21
+0.22
 
 =cut
